@@ -3,16 +3,25 @@ import importlib
 from lutris import settings
 from lutris.util.log import logger
 
-MIGRATION_VERSION = 12  # Never decrease this number
+MIGRATION_VERSION = 15  # Never decrease this number
 
 # Replace deprecated migrations with empty lists
 MIGRATIONS = [
-    [], [], [], [], [], [], [],
+    [],
+    [],
+    [],
+    [],
+    [],
+    [],
+    [],
     ["mess_to_mame"],
     ["migrate_hidden_ids"],
     ["migrate_steam_appids"],
-    ["migrate_banners"],
+    [],
     ["retrieve_discord_appids"],
+    ["migrate_sortname"],
+    ["migrate_hidden_category"],
+    ["migrate_ge_proton"],
 ]
 
 
