@@ -1,5 +1,10 @@
 import os
 
+import gi
+
+gi.require_version("Gdk", "3.0")
+gi.require_version("Gtk", "3.0")
+
 from lutris import startup
 from lutris.database import schema
 
