@@ -49,6 +49,7 @@ Linux release.
 
 This module's code is based on https://gist.github.com/openglfreak/715d5ab5902497378f1996061dbbf8ec
 """
+
 import ctypes
 import errno
 import os
@@ -67,6 +68,7 @@ class timespec(ctypes.Structure):
         tv_sec: The whole seconds of the timespec.
         tv_nsec: The nanoseconds of the timespec.
     """
+
     __slots__ = ()
     _fields_ = [
         ("tv_sec", ctypes.c_long),
@@ -79,42 +81,32 @@ def _get_syscall_nr_from_headers(syscall_name):
 
     try:
         with subprocess.Popen(
-                ("cpp", "-m" + str(bits), "-E", "-P", "-x", "c", "-"),
-                stdin=subprocess.PIPE,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE,
-                close_fds=True,
-                universal_newlines=True,
+            ("cpp", "-m" + str(bits), "-E", "-P", "-x", "c", "-"),
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            close_fds=True,
+            universal_newlines=True,
         ) as popen:
-            stdout, stderr = popen.communicate(
-                "#include <sys/syscall.h>\n"
-                "__NR_" + syscall_name + "\n"
-            )
+            stdout, stderr = popen.communicate("#include <sys/syscall.h>\n" "__NR_" + syscall_name + "\n")
     except FileNotFoundError as ex:
         raise RuntimeError(
-            "failed to determine " + syscall_name + " syscall number: "
-            "cpp not installed or not in PATH"
+            "failed to determine " + syscall_name + " syscall number: " "cpp not installed or not in PATH"
         ) from ex
 
     if popen.returncode:
         raise RuntimeError(
-            "failed to determine " + syscall_name + " syscall number: "
-            "cpp returned nonzero exit code",
-            stderr
+            "failed to determine " + syscall_name + " syscall number: " "cpp returned nonzero exit code", stderr
         )
 
     if not stdout:
-        raise RuntimeError(
-            "failed to determine " + syscall_name + " syscall number: "
-            "no output from cpp"
-        )
+        raise RuntimeError("failed to determine " + syscall_name + " syscall number: " "no output from cpp")
 
     last_line = stdout.splitlines()[-1]
 
     if last_line == "__NR_futex":
         raise RuntimeError(
-            "failed to determine " + syscall_name + " syscall number: "
-            "__NR_" + syscall_name + " not expanded"
+            "failed to determine " + syscall_name + " syscall number: " "__NR_" + syscall_name + " not expanded"
         )
 
     try:
@@ -158,15 +150,11 @@ def _get_futex_syscall_nr():
     except KeyError:
         pass
 
-    return _get_syscall_nr_from_headers('futex')
+    return _get_syscall_nr_from_headers("futex")
 
 
 def _is_ctypes_obj(obj):
-    return (
-        hasattr(obj, "_b_base_")
-        and hasattr(obj, "_b_needsfree_")
-        and hasattr(obj, "_objects")
-    )
+    return hasattr(obj, "_b_base_") and hasattr(obj, "_b_needsfree_") and hasattr(obj, "_objects")
 
 
 def _is_ctypes_obj_pointer(obj):
@@ -198,9 +186,15 @@ def _get_futex_syscall():
         RuntimeError: When the syscall number could not be determined.
     """
     futex_syscall = ctypes.CDLL(None, use_errno=True).syscall
-    futex_syscall.argtypes = (ctypes.c_long, ctypes.c_void_p, ctypes.c_int,
-                              ctypes.c_int, ctypes.POINTER(timespec),
-                              ctypes.c_void_p, ctypes.c_int)
+    futex_syscall.argtypes = (
+        ctypes.c_long,
+        ctypes.c_void_p,
+        ctypes.c_int,
+        ctypes.c_int,
+        ctypes.POINTER(timespec),
+        ctypes.c_void_p,
+        ctypes.c_int,
+    )
     futex_syscall.restype = ctypes.c_int
     futex_syscall_nr = _get_futex_syscall_nr()
 
@@ -231,7 +225,7 @@ def _get_futex_syscall():
             val,
             _coerce_to_pointer(timeout or timespec()),
             _coerce_to_pointer(uaddr2),
-            val3
+            val3,
         )
         return error, (ctypes.get_errno() if error == -1 else 0)
 
@@ -316,7 +310,7 @@ def _get_futex_waitv_syscall_nr():
     except KeyError:
         pass
 
-    return _get_syscall_nr_from_headers('futex_waitv')
+    return _get_syscall_nr_from_headers("futex_waitv")
 
 
 # pylint: disable=invalid-name,too-few-public-methods
@@ -328,6 +322,7 @@ class futex_waitv(ctypes.Structure):
         uaddr: The address to wait for.
         flags: The type and size of the futex.
     """
+
     __slots__ = ()
     _fields_ = [
         ("val", ctypes.c_uint64),
@@ -348,9 +343,13 @@ def _get_futex_waitv_syscall():
         RuntimeError: When the syscall number could not be determined.
     """
     futex_waitv_syscall = ctypes.CDLL(None, use_errno=True).syscall
-    futex_waitv_syscall.argtypes = (ctypes.c_long, ctypes.POINTER(futex_waitv),
-                                    ctypes.c_uint, ctypes.c_uint,
-                                    ctypes.POINTER(timespec))
+    futex_waitv_syscall.argtypes = (
+        ctypes.c_long,
+        ctypes.POINTER(futex_waitv),
+        ctypes.c_uint,
+        ctypes.c_uint,
+        ctypes.POINTER(timespec),
+    )
     futex_waitv_syscall.restype = ctypes.c_long
     futex_waitv_syscall_nr = _get_futex_waitv_syscall_nr()
 
@@ -376,11 +375,7 @@ def _get_futex_waitv_syscall():
                 converted into one.
         """
         error = futex_waitv_syscall(
-            futex_waitv_syscall_nr,
-            _coerce_to_pointer(waiters),
-            nr_futexes,
-            flags,
-            _coerce_to_pointer(timeout)
+            futex_waitv_syscall_nr, _coerce_to_pointer(waiters), nr_futexes, flags, _coerce_to_pointer(timeout)
         )
         return error, (ctypes.get_errno() if error == -1 else 0)
 
